searchData={"items":[{"type":"module","title":"CredoBinaryPatterns.Check.Consistency.Pattern","doc":"This check has a base priority of `high` and works with any version of Elixir.","ref":"CredoBinaryPatterns.Check.Consistency.Pattern.html"},{"type":"module","title":"Explanation - CredoBinaryPatterns.Check.Consistency.Pattern","doc":"","ref":"CredoBinaryPatterns.Check.Consistency.Pattern.html#module-explanation"},{"type":"module","title":"Check-Specific Parameters - CredoBinaryPatterns.Check.Consistency.Pattern","doc":"*There are no specific parameters for this check.*","ref":"CredoBinaryPatterns.Check.Consistency.Pattern.html#module-check-specific-parameters"},{"type":"module","title":"General Parameters - CredoBinaryPatterns.Check.Consistency.Pattern","doc":"Like with all checks, [general params](check_params.html) can be applied.\n\nParameters can be configured via the [`.credo.exs` config file](config_file.html).","ref":"CredoBinaryPatterns.Check.Consistency.Pattern.html#module-general-parameters"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.2.2 - Changelog","doc":"* Create more specific rules around `bytes`, `binary`, and `size(x)` in patterns. ([#7](https://github.com/smartrent/credo_binary_patterns/pull/7)).\n* Fix not handling `unit` correctly.","ref":"changelog.html#v0-2-2"},{"type":"extras","title":"v0.2.1 - Changelog","doc":"* Adds special case for `bytes` and `binary` options. Size should be specified before these types.","ref":"changelog.html#v0-2-1"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"* Improve AST parser logic to handle 2, 3, and 4 element patterns.\n* Pretty print the pattern in the correct format, along with the issue.\n* Initial Hex release 🎉","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"CredoBinaryPatterns","doc":"# CredoBinaryPatterns\n\n[![CircleCI](https://circleci.com/gh/smartrent/credo_binary_patterns.svg?style=svg)](https://circleci.com/gh/smartrent/credo_binary_patterns)\n[![Hex version](https://img.shields.io/hexpm/v/credo_binary_patterns.svg \"Hex version\")](https://hex.pm/packages/credo_binary_patterns)\n\nThe `:credo_binary_patterns` library contains Credo checks for\nwriting consistent binary patterns. Elixir lets you do whatever you want.\nThe checks in this library do not.","ref":"readme.html"},{"type":"extras","title":"Installation - CredoBinaryPatterns","doc":"Add the `:credo_binary_patterns` package to your `mix.exs` dependencies:\n\n```elixir\ndef deps do\n  [\n    {:credo_binary_patterns, \"~> 0.2.2\", only: [:dev, :test], runtime: false}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - CredoBinaryPatterns","doc":"Add the check to your `.credo.exs` configuration file.\n\n#","ref":"readme.html#usage"},{"type":"extras","title":"Ensure pattern consistency - CredoBinaryPatterns","doc":"This check will raise issues if any binary patterns in your code do not follow the expected ordering or formatting.\n\n```elixir\n{CredoBinaryPatterns.Check.Consistency.Pattern}\n```","ref":"readme.html#ensure-pattern-consistency"},{"type":"extras","title":"Conventions Checked By This Library - CredoBinaryPatterns","doc":"#","ref":"readme.html#conventions-checked-by-this-library"},{"type":"extras","title":"Ordering of Options - CredoBinaryPatterns","doc":"For `float`, `integer`, and `binary` patterns should follow this ordering of options:\n\n```\n >\n```\n\nWhen using `bytes`, the size comes **_before_** the type option:\n\n```\n >\n```\n\n#","ref":"readme.html#ordering-of-options"},{"type":"extras","title":"Do not specify unnecessary options - CredoBinaryPatterns","doc":"Avoid providing default sizes, endians, or sign options with their respective types.\n\nFor example:\n\n```elixir\n# Incorrect - integers default to 8 bits\n >\n\n# Incorrect - integers default to big-endian\n >\n```\n\nSee the [Elixir Documentation](https://hexdocs.pm/elixir/1.13.4/Kernel.SpecialForms.html#%3C%3C%3E%3E/1-types) for more information on defaults.)\n\n#","ref":"readme.html#do-not-specify-unnecessary-options"},{"type":"extras","title":"Do not use `size()` with `bytes` - CredoBinaryPatterns","doc":"If you need to use `size()`, use the `binary` type instead.\n\n```elixir\n# Incorrect\n >\n\n# Re-write as `binary` if you want to use `size`\n >\n\n# This is also a valid re-write\n >\n```\n\n#","ref":"readme.html#do-not-use-size-with-bytes"},{"type":"extras","title":"Do not use bare sizes with `binary` - CredoBinaryPatterns","doc":"If you use bare numeric values as a size in a `binary` pattern, consider using `bytes` instead. Or, if consistent with the rest of the pattern, use `size()`.\n```elixir\n# Incorrect\n >\n\n# Re-write as `bytes`\n >\n\n# This is also a valid re-write\n >\n```","ref":"readme.html#do-not-use-bare-sizes-with-binary"},{"type":"extras","title":"Example Issue Output - CredoBinaryPatterns","doc":"Suppose you write the following code:\n\n```elixir\ndefmodule Test do\n  def test do\n    # This pattern is out of order (size comes before type)\n     >\n\n    # This pattern does not need to specify the size (integers default to `8`)\n     >\n\n    # This pattens does not need to specify the endian (integers default to `big`)\n     >\n  end\nend\n```\n\nCredo will warn you about the formatting issues:\n\n```\n$ mix credo\n\n  Consistency\n┃ \n┃ [C] ↗ [Unneeded endian specified] Please re-write this binary pattern as  >\n┃       test.ex:10:8 #(Test.test)\n┃ [C] ↗ [Unneeded size specified] Please re-write this binary pattern as  >\n┃       test.ex:7:8 #(Test.test)\n┃ [C] ↗ [Options out of order] Should follow: [endian]-[sign]-[type]-[size]. Please re-write this binary pattern as  >\n┃       test.ex:4:8 #(Test.test)\n```","ref":"readme.html#example-issue-output"},{"type":"extras","title":"License - CredoBinaryPatterns","doc":"This library is licensed under the MIT License like Credo.\n\n```text\nCopyright (C) 2023 SmartRent\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.\n```","ref":"readme.html#license"}],"content_type":"text/markdown"}